@@ -4,6 +4,7 @@ use warnings;
 package MooseX::Role::REST::Consumer::UserAgent::Curl;
 
 use Moose;
+use HTTP::Headers;
 extends 'WWW::Curl::UserAgent';
 
 sub agent {
@@ -13,7 +14,7 @@ sub agent {
 #FIXME: version of libcurl that we have has a bug in subsecond timeouts
 has '+connect_timeout' => ( default => sub { 1000 } );
 
-sub default_headers { };
+sub default_headers { HTTP::Headers->new };
 sub use_eval {};
 
 sub timeout {
